# Translation Comparator

It is a statically typed library that нelps to compare translated code.

## Cython

Will remove most of the useless difference between files so you can focus on the important difference.

[Example of use with cython](https://github.com/0dminnimda/translation_comparator/blob/main/examples/cython/run_cython_comparison.py)

## Library Installation

Available on PyPI:

```console
python -m pip install translation_comparator
```

### Installing optional dependencies

For example, this is how you can install a package with the required dependencies to work with cython.

```console
python -m pip install translation_comparator[cython]
```

## Upgrading

```console
python -m pip install -U translation_comparator
```
